@@ -66,13 +66,15 @@ class IMAPEmailHandler(object):
 
     def get_waiting_emails(self):
         """Fetch all waiting messages"""
-        res, data = self.connection.search(None, u"NOT KEYWORD imported", u"NOT KEYWORD unsupported",
-                                           u"NOT KEYWORD error")
+        res, data = self.connection.search(None,
+                                           u"NOT KEYWORD imported", u"NOT KEYWORD unsupported", u"NOT KEYWORD error")
+                                           # u"KEYWORD error")
         if res != "OK":
             logger.error("Unable to fetch mails")
             return []
         waiting = []
         for mail_id in data[0].split():
+            # if mail_id != b'771': continue
             mail = self.get_mail(mail_id)
             if not mail:
                 continue
@@ -116,6 +118,27 @@ class IMAPEmailHandler(object):
             logger.info(lst[-1])
         return lst
 
+    def stats(self):
+        """List all flags"""
+        res, data = self.connection.search(None, 'ALL')
+        if res != "OK":
+            logger.error("Unable to fetch mails")
+            return []
+        lst = []
+        stats = {'tot': 0, 'flags': {}}
+        for mail_id in data[0].split():
+            stats['tot'] += 1
+            res, flags_data = self.connection.fetch(mail_id, '(FLAGS)')
+            if res != "OK":
+                logger.error("Unable to fetch flags for mail {0}".format(mail_id))
+                continue
+            for flag in imaplib.ParseFlags(flags_data[0]):
+                flag = flag.decode()
+                if flag not in stats['flags']:
+                    stats['flags'][flag] = 0
+                stats['flags'][flag] += 1
+        return stats
+
     def mark_reset_error(self, mail_id):
         """Reset 'error' / 'waiting' flags on specified mail"""
         self.connection.store(mail_id, "-FLAGS", "imported")
