@@ -2,7 +2,7 @@
 
 """
 Usage: process_mails FILE [--requeue_errors] [--list_emails=<number>] [--get_eml=<mail_id>]  [--gen_pdf=<mail_id>]
-                          [--get_eml_orig]
+                          [--get_eml_orig] [--stats]
 
 Arguments:
     FILE         config file
@@ -14,6 +14,7 @@ Options:
     --get_eml=<mail_id>     Get eml of original/contained email id.
     --get_eml_orig          Get eml of original email id (otherwise contained).
     --gen_pdf=<mail_id>     Generate pdf of contained email id.
+    --stats                 Get email stats following stats
 """
 
 from datetime import datetime
@@ -24,6 +25,7 @@ from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from hashlib import md5
 from imio.email.dms.imap import IMAPEmailHandler
+from imio.email.dms.imap import MailData
 from imio.email.dms.utils import safe_unicode
 from imio.email.parser.parser import Parser  # noqa
 from io import BytesIO
@@ -314,6 +316,12 @@ def process_mails():
         handler.list_last_emails(nb=int(arguments.get("--list_emails")))
         # import ipdb; ipdb.set_trace()
         # handler.mark_reset_error('58')
+        # res, data = handler.connection.search(None, 'SUBJECT "JBC client"')
+        # for mail_id in data[0].split():
+        #      mail = handler.get_mail(mail_id)
+        #      mail_infos = MailData(mail_id, mail)
+        #      email = mail_infos.mail
+        #     logger.info(email['Subject'])
         handler.disconnect()
         lock.close()
         sys.exit()
@@ -347,6 +355,16 @@ def process_mails():
         handler.disconnect()
         lock.close()
         sys.exit()
+    elif arguments.get("--stats"):
+        logger.info('Started at {}'.format(datetime.now()))
+        stats = handler.stats()
+        logger.info("Total mails: {}".format(stats.pop('tot')))
+        for flag in sorted(stats['flags']):
+            logger.info("Flag '{}' => {}".format(flag, stats['flags'][flag]))
+        handler.disconnect()
+        lock.close()
+        logger.info('Ended at {}'.format(datetime.now()))
+        sys.exit()
 
     imported = errors = unsupported = 0
     for mail_info in handler.get_waiting_emails():
